==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220411.043058-74-sources.jar: com/tydic/dyc/oc/repository/po/UocSaleStakeholderPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocSaleStakeholderPo
 * 说明:记录买方、卖方、平台三方信息
 * 时间:2022-02-25 16:35
 * 作者:罗有
 **/
@Data
public class UocSaleStakeholderPo implements Serializable {
	private static final long serialVersionUID = -932302674152638443L;

	@DocField(value = "三方信息id")
	private Long stakeholderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "采购方账套id")
	private String purAccount;

	@DocField(value = "采购方账套名称")
	private String purAccountName;

	@DocField(value = "采购方联系人")
	private String purContactName;

	@DocField(value = "采购方联系人电话")
	private String purMobile;

	@DocField(value = "采购方下单人用户id")
	private String purUserId;

	@DocField(value = "采购方下单人真实姓名")
	private String purName;

	@DocField(value = "采购方下单人登录名")
	private String purUserName;

	@DocField(value = "采购方公司id")
	private String purCompanyId;

	@DocField(value = "采购公司编码")
	private String purCompanyNo;

	@DocField(value = "采购方公司名称")
	private String purCompanyName;

	@DocField(value = "采购方机构id")
	private String purOrgId;

	@DocField(value = "采购方机构编码")
	private String purOrgNo;

	@DocField(value = "采购方机构名称")
	private String purOrgName;

	@DocField(value = "下单组织机构路径")
	private String purOrgPath;

	@DocField(value = "需方联系人名称")
	private String purNeedName;

	@DocField(value = "需方联系电话")
	private String purNeedMobile;

	@DocField(value = "供应商id")
	private String supId;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商名称")
	private String supName;

	@DocField(value = "供应商联系人")
	private String supRelaName;

	@DocField(value = "供应商联系电话")
	private String supRelaMobile;

	@DocField(value = "运营单位机构id")
	private String proId;

	@DocField(value = "运营单位机构编码")
	private String proNo;

	@DocField(value = "运营机构名称")
	private String proName;

	@DocField(value = "运营机构机构树路径")
	private String proOrgPath;

	@DocField(value = "运营机构账户名称")
	private String proAccountName;

	@DocField(value = "运营机构账户")
	private String proAccount;

	@DocField(value = "运营机构联系人")
	private String proRelaName;

	@DocField(value = "运营机构联系电话")
	private String proRelaMobile;

	@DocField(value = "协议经办人id（配送专责）")
	private String proDeliveryId;

	@DocField(value = "协议经办人名字（配送专责）")
	private String proDeliveryName;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "扩展字段1")
	private String extField1;

	@DocField(value = "扩展字段2")
	private String extField2;

	@DocField(value = "扩展字段3")
	private String extField3;

	@DocField(value = "扩展字段4")
	private String extField4;

	@DocField(value = "扩展字段5")
	private String extField5;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230731.024100-76-sources.jar: com/tydic/dyc/oc/repository/po/UocSaleStakeholderPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocSaleStakeholderPo
 * 说明:记录买方、卖方、平台三方信息
 * 时间:2022-04-20 10:21
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocSaleStakeholderPo implements Serializable {
	private static final long serialVersionUID = 3214931473426699280L;

	//三方信息id")
	private Long stakeholderId;

	//订单id")
	private Long orderId;

	//采购方账套id")
	private String purAccount;

	//采购方账套名称")
	private String purAccountName;

	//采购方联系人")
	private String purContactName;

	//采购方联系人电话")
	private String purMobile;

	//采购方下单人用户id")
	private String purUserId;

	//采购方下单人真实姓名")
	private String purName;

	//采购方下单人登录名")
	private String purUserName;

	//采购方公司id")
	private String purCompanyId;

	//采购公司编码")
	private String purCompanyNo;

	//采购方公司名称")
	private String purCompanyName;

	//采购方机构id")
	private String purOrgId;

	//采购方机构编码")
	private String purOrgNo;

	//采购方机构名称")
	private String purOrgName;

	//下单组织机构路径")
	private String purOrgPath;

	//需方联系人名称")
	private String purNeedName;

	//需方联系电话")
	private String purNeedMobile;

	//供应商id")
	private String supId;

	//供应商编码")
	private String supNo;

	//供应商名称")
	private String supName;

	//供应商联系人")
	private String supRelaName;

	//供应商联系电话")
	private String supRelaMobile;

	//运营单位机构id")
	private String proId;

	//运营单位机构编码")
	private String proNo;

	//运营机构名称")
	private String proName;

	//运营机构机构树路径")
	private String proOrgPath;

	//运营机构账户名称")
	private String proAccountName;

	//运营机构账户")
	private String proAccount;

	//运营机构联系人")
	private String proRelaName;

	//运营机构联系电话")
	private String proRelaMobile;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//扩展字段1")
	private String extField1;

	//扩展字段2")
	private String extField2;

	//扩展字段3")
	private String extField3;

	//扩展字段4")
	private String extField4;

	//扩展字段5")
	private String extField5;

	//排序")
	private String orderBy;
	//供应商机构树")
	private String supOrgPath;


}
